==> jec-wildcat-1.0.0.tgz: package/test/com/onsoft/wildcat/context/ProjectTest.ts <==
//  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
//
//   Copyright 2016-2017 Pascal ECHEMANN.
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

import { TestSuite, Test, BeforeClass } from "jec-juta";
import { expect } from "chai";
import { Project } from "../../../../../src/com/onsoft/wildcat/context/Project";

@TestSuite({
  description: "Test the Project class properties"
})
export class ProjectTest {

  public project:Project = null;

  @BeforeClass()
  public initProject():void {
    this.project = new Project();
  }

  @Test({
    description: "should have a 'version' property set to 'null'"
  })
  public versionTest():void {
    expect(this.project).to.have.property("version", null);
  }
  
  @Test({
    description: "should have a 'title' property set to 'null'"
  })
  public titleTest():void {
    expect(this.project).to.have.property("title", null);
  }
  
  @Test({
    description: "should have a 'description' property set to 'null'"
  })
  public descriptionTest():void {
    expect(this.project).to.have.property("description", null);
  }
  
  @Test({
    description: "should have a 'author' property set to 'null'"
  })
  public authorTest():void {
    expect(this.project).to.have.property("author", null);
  }
}

==> jec-wildcat-1.0.2.tgz: package/test/com/onsoft/wildcat/context/ProjectTest.ts <==
//  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
//
//   Copyright 2016-2017 Pascal ECHEMANN.
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

import { TestSuite, Test, BeforeAll } from "jec-juta";
import { expect } from "chai";
import { Project } from "../../../../../src/com/onsoft/wildcat/context/Project";

@TestSuite({
  description: "Test the Project class properties"
})
export class ProjectTest {

  public project:Project = null;

  @BeforeAll()
  public initTest():void {
    this.project = new Project();
  }

  @Test({
    description: "should have a 'version' property set to 'null'"
  })
  public versionTest():void {
    expect(this.project).to.have.property("version", null);
  }
  
  @Test({
    description: "should have a 'title' property set to 'null'"
  })
  public titleTest():void {
    expect(this.project).to.have.property("title", null);
  }
  
  @Test({
    description: "should have a 'description' property set to 'null'"
  })
  public descriptionTest():void {
    expect(this.project).to.have.property("description", null);
  }
  
  @Test({
    description: "should have a 'author' property set to 'null'"
  })
  public authorTest():void {
    expect(this.project).to.have.property("author", null);
  }
}
